-------------------------------
IndexedList and Table
-------------------------------

IndexedList is a list that has a number of indexes on its items.
Table is subclass of IndexedList functionally similar to SQL table.
Documentation soon. Refer to tests for usage examples.
